DecodePrivateKey

Trait DecodePrivateKey 

pub trait DecodePrivateKey: Sized {
    // Required method
    fn from_pkcs8_der(bytes: &[u8]) -> Result<Self>;

    // Provided methods
    fn from_pkcs8_pem(s: &str) -> Result<Self> { ... }
    fn read_pkcs8_der_file(path: impl AsRef<Path>) -> Result<Self> { ... }
    fn read_pkcs8_pem_file(path: impl AsRef<Path>) -> Result<Self> { ... }
}
Parse a private key object from a PKCS#8 encoded document.

Required Methods

fn from_pkcs8_der(bytes: &[u8]) -> Result<Self>

Deserialize PKCS#8 private key from ASN.1 DER-encoded data (binary format).

Errors

Returns format-specific errors in the event the document failed to parse.

Provided Methods

fn from_pkcs8_pem(s: &str) -> Result<Self>

Deserialize PKCS#8-encoded private key from PEM.

Keys in this format begin with the following delimiter:

-----BEGIN PRIVATE KEY-----
Errors
fn read_pkcs8_der_file(path: impl AsRef<Path>) -> Result<Self>

Load PKCS#8 private key from an ASN.1 DER-encoded file (binary format) on the local filesystem.

Errors
fn read_pkcs8_pem_file(path: impl AsRef<Path>) -> Result<Self>

Load PKCS#8 private key from a PEM-encoded file on the local filesystem.

Errors

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors